@@ -102,7 +102,7 @@ class SyncDriver:
             self.last_start = time.clock_gettime_ns(self.clock_id)
 
             if self.pre_callback != None:
-                self.pre_callback()
+                self.pre_callback(conn)
 
             while True and self.running:
                 try:
@@ -113,7 +113,7 @@ class SyncDriver:
                 except NoBlockForYou as e:
                     break
                 if self.block_callback != None:
-                    self.block_callback(block, None)
+                    self.block_callback(conn, block)
 
                 try:
                     self.process(conn, item, block)
@@ -125,7 +125,7 @@ class SyncDriver:
                     self.running = False
 
             if self.post_callback != None:
-                self.post_callback()
+                self.post_callback(conn)
    
 
             self.idle(interval)
